@@ -48,10 +48,8 @@ sub send_command {
             $self->_notify_handler()->($reply);
         }
     } else {
-        if ($command->{blocking}) {
-            while (!$command->{reply}) {
-                $self->sleep;
-            }
+        while (!$command->{reply}) {
+            $self->sleep;
         }
     }
     $self->handler->call('Command', _ => $command);
@@ -119,20 +117,26 @@ Skype::Any::API - API interface for Skype::Any
 
 =head2 C<run>
 
-  $api->run();
+Running an event loop.
 
 =head2 C<is_running>
 
-  $api->is_running();
+  $api->is_running;
+
+Return 1 when Skype is running and 0 otherwise.
 
 =head2 C<send_command>
 
   $api->send_command($cmd, $expected);
 
-=head1 ATTRIBUTES
+Send Skype API string. This method returns new instance of L<Skype::Any::Commond>. If you want reply command sent:
 
-=head2 C<c>
+  $api->send_command($cmd)->reply();
+
+=head1 ATTRIBUTES
 
 =head2 C<handler>
 
+Instance of C<Skype::Any::Handler>.
+
 =cut
