@@ -11,7 +11,6 @@ sub new {
     return bless {
         command  => $command,
         id       => -1,
-        blocking => 1,
         reply    => '',
         %$args,
     }, $class;
@@ -57,4 +56,6 @@ Return a list of command which is split. $limit is by default 4. It means that c
 
 =head2 C<reply>
 
+Reply command sent.
+
 =cut
